@@ -1,13 +1,11 @@
 from enum import auto, Enum
 from typing import Dict, List, Optional, TYPE_CHECKING, Union
 
-from mstrio.access_and_security.security_filter import (AttributeElement, AttributeFormNormalRef,
-                                                        AttributeFormSystemRef, AttributeRef,
-                                                        ConstantArrayParameter, ConstantParameter,
-                                                        DynamicDateTimeParameter, ElementPromptRef,
-                                                        ExpressionParameter, FilterRef,
-                                                        ObjectReferenceParameter, ParameterType,
-                                                        PromptParameter)
+from mstrio.access_and_security.security_filter import (
+    AttributeElement, AttributeFormNormalRef, AttributeFormSystemRef, AttributeRef,
+    ConstantArrayParameter, ConstantParameter, DynamicDateTimeParameter, ElementPromptRef,
+    ExpressionParameter, FilterRef, ObjectReferenceParameter, ParameterType, PromptParameter
+)
 from mstrio.utils.enum_helper import AutoName
 from mstrio.utils.helper import Any, camel_to_snake, delete_none_values, Dictable, snake_to_camel
 
@@ -19,6 +17,7 @@ if TYPE_CHECKING:
 class PredicateBase(Dictable):
 
     TYPE = None
+    _DELETE_NONE_VALUES_RECURSION = False
 
     def _create_predicate_tree(self, **kwargs):
         return None
@@ -31,7 +30,7 @@ class PredicateBase(Dictable):
             "type": self.type,
             "predicate_id": self.predicate_id,
             "predicate_tree": self._predicate_tree_to_dict(camel_case)
-        })
+        }, recursion=True)
         return snake_to_camel(result) if camel_case else result
 
     def __init__(self, predicate_id: Optional[str] = None, **kwargs):
@@ -64,6 +63,7 @@ class PredicateFormFunction(AutoName):
 class PredicateForm(PredicateBase):
     # Attribute Form Predicate
     TYPE = 'predicate_form_qualification'
+    _DELETE_NONE_VALUES_RECURSION = False
 
     def _create_predicate_tree(self, **kwargs):
         self.function = kwargs.get("function")
@@ -187,6 +187,7 @@ class PredicateElementListFunction(Enum):
 class PredicateElementList(PredicateBase):
     # Element List Predicate
     TYPE = 'predicate_element_list'
+    _DELETE_NONE_VALUES_RECURSION = False
 
     def _create_predicate_tree(self, **kwargs):
         self.function = kwargs.get("function")
@@ -266,6 +267,7 @@ class PredicateElementList(PredicateBase):
 class PredicateFilter(PredicateBase):
     # Filter Qualification Predicate
     TYPE = 'predicate_filter_qualification'
+    _DELETE_NONE_VALUES_RECURSION = False
 
     def _create_predicate_tree(self, **kwargs):
         self.filter = kwargs.get("filter")
@@ -324,6 +326,7 @@ class PredicateFilter(PredicateBase):
 class PredicateJointElementList(PredicateBase):
     # Joint Element List Predicate
     TYPE = 'predicate_joint_element_list'
+    _DELETE_NONE_VALUES_RECURSION = False
 
     def _create_predicate_tree(self, **kwargs):
         self.level = kwargs.get("level")
@@ -400,6 +403,7 @@ class LogicFunction(AutoName):
 class LogicOperator(Dictable):
 
     TYPE = "operator"
+    _DELETE_NONE_VALUES_RECURSION = False
 
     def __init__(self, function: "LogicFunction", children: Union["LogicOperator",
                                                                   "PredicateBase"]):
@@ -412,7 +416,7 @@ class LogicOperator(Dictable):
             "type": self.type,
             "function": self.function.value,
             "children": [child.to_dict(camel_case) for child in self.children]
-        })
+        }, recursion=True)
         return snake_to_camel(result) if camel_case else result
 
     @classmethod
