@@ -1,12 +1,13 @@
 from enum import auto
+import logging
 from typing import List, Optional, TYPE_CHECKING, Union
 
 from mstrio import config
 from mstrio.api import datasources, objects
-from mstrio.datasources import DatasourceConnection, Dbms
+from mstrio.datasources import DatasourceConnection, Dbms, list_datasource_connections
 from mstrio.users_and_groups.user import User
 from mstrio.utils import helper
-from mstrio.utils.entity import DeleteMixin, CopyMixin, Entity, ObjectTypes
+from mstrio.utils.entity import CopyMixin, DeleteMixin, Entity, ObjectTypes
 from mstrio.utils.enum_helper import AutoName, get_enum_val
 from mstrio.utils.helper import get_objects_id
 
@@ -14,6 +15,8 @@ if TYPE_CHECKING:
     from mstrio.connection import Connection
     from mstrio.server.project import Project
 
+logger = logging.getLogger(__name__)
+
 
 def list_datasource_instances(connection: "Connection", to_dictionary: bool = False,
                               limit: Optional[int] = None, ids: Optional[List[str]] = None,
@@ -75,6 +78,40 @@ def list_datasource_instances(connection: "Connection", to_dictionary: bool = Fa
     )
 
 
+def list_connected_datasource_instances(
+        connection: "Connection",
+        to_dictionary: bool = False) -> Union[list["DatasourceInstance"], list[dict]]:
+    """List all datasource instances for which there is an associated
+    Database Login and are connected to a project mapped to a Connection object.
+
+    Args:
+        connection (Connection): MicroStrategy connection object returned by
+            `connection.Connection()`
+        to_dictionary (bool, optional): If True returns a list of dictionaries
+            representing datasource instances
+
+    Returns:
+        Union[list["DatasourceInstance"], list[dict]]: A list of connected
+            datasource instances.
+    """
+    all_datasource_instances = list_datasource_instances(connection, to_dictionary=True)
+    datasource_connections_ids = [
+        ds_connection.get('id')
+        for ds_connection in list_datasource_connections(connection, to_dictionary=True)
+    ]
+    connected_datasource_instances = [
+        ds_instance for ds_instance in all_datasource_instances
+        if ds_instance.get('datasource_connection').get('id') in datasource_connections_ids
+    ]
+
+    if to_dictionary:
+        return connected_datasource_instances
+    return [
+        DatasourceInstance.from_dict(source=ds_instance, connection=connection)
+        for ds_instance in connected_datasource_instances
+    ]
+
+
 class DatasourceType(AutoName):
     RESERVED = auto()
     NORMAL = auto()
@@ -108,6 +145,7 @@ class DatasourceInstance(Entity, CopyMixin, DeleteMixin):
         acl: Object access control list
     """
 
+    _DELETE_NONE_VALUES_RECURSION = False
     _OBJECT_TYPE = ObjectTypes.DBROLE
     _FROM_DICT_MAP = {
         **Entity._FROM_DICT_MAP, 'dbms': Dbms.from_dict,
@@ -140,10 +178,10 @@ class DatasourceInstance(Entity, CopyMixin, DeleteMixin):
         "intermediate_store_db_name": str,
         "intermediate_store_table_space_name": str,
         "odbc_version": str,
-        "datasource_connection": str,
-        "primary_datasource": str,
-        "data_mart_datasource": str,
-        "dbms": str,
+        "datasource_connection": dict,
+        "primary_datasource": dict,
+        "data_mart_datasource": dict,
+        "dbms": dict,
     }
 
     def __init__(self, connection: "Connection", name: Optional[str] = None,
@@ -228,8 +266,8 @@ class DatasourceInstance(Entity, CopyMixin, DeleteMixin):
             intermediate_store_table_space_name: intermediate store table space
                 name
             datasource_connection: `DatasourceConnection` object or ID
-            database_type: Databse type
-            database_version: Databse version
+            database_type: Database type
+            database_version: Database version
             primary_datasource: `DatasourceInstance` object or ID
             data_mart_datasource: `DatasourceInstance` object or ID
 
@@ -265,11 +303,12 @@ class DatasourceInstance(Entity, CopyMixin, DeleteMixin):
                 "id": dbms_id
             }
         }
-        body = helper.delete_none_values(body)
+        body = helper.delete_none_values(body, recursion=True)
         response = datasources.create_datasource_instance(connection, body).json()
         if config.verbose:
-            print("Successfully created datasource instance named: '{}' with ID: '{}'".format(
-                response.get('name'), response.get('id')))
+            logger.info(
+                f"Successfully created datasource instance named: '{response.get('name')}' "
+                f"with ID: '{response.get('id')}'")
         return cls.from_dict(source=response, connection=connection)
 
     def alter(self, name: Optional[str] = None, description: Optional[str] = None,
@@ -299,6 +338,16 @@ class DatasourceInstance(Entity, CopyMixin, DeleteMixin):
             data_mart_datasource: `DatasourceInstance` object or ID
 
         """
+        dbms = {'id': get_objects_id(dbms, Dbms)} if dbms else None
+        datasource_connection = {
+            'id': get_objects_id(datasource_connection, DatasourceConnection)
+        } if datasource_connection else None
+        primary_datasource = {
+            'id': get_objects_id(primary_datasource, self)
+        } if primary_datasource else None
+        data_mart_datasource = {
+            'id': get_objects_id(data_mart_datasource, self)
+        } if data_mart_datasource else None
         func = self.alter
         args = func.__code__.co_varnames[:func.__code__.co_argcount]
         defaults = func.__defaults__  # type: ignore
@@ -327,8 +376,8 @@ class DatasourceInstance(Entity, CopyMixin, DeleteMixin):
         else:
             return [cls.from_dict(source=obj, connection=connection) for obj in objects]
 
-    def _set_object(self, **kwargs) -> None:
-        super(DatasourceInstance, self)._set_object(**kwargs)
+    def _set_object_attributes(self, **kwargs) -> None:
+        super()._set_object_attributes(**kwargs)
         if kwargs.get("primary_datasource"):
             setattr(
                 self, 'primary_datasource',
