@@ -47,6 +47,8 @@ class LibraryCacheTypes(AutoName):
 
 
 class DeliveryDictable(Dictable):
+    _DELETE_NONE_VALUES_RECURSION = False
+
     VALIDATION_DICT = {}
 
     @classmethod
@@ -71,7 +73,7 @@ class DeliveryDictable(Dictable):
                     "{} has incorrect type {}. Correct type is {}.".format(
                         key, type(value), vtype), TypeError)
             elif value is None and obligatory:
-                exception_handler("{} is obligatory and cannot be empty.".format(key), ValueError)
+                exception_handler(f"{key} is obligatory and cannot be empty.", ValueError)
 
 
 class ZipSettings(DeliveryDictable):
@@ -82,6 +84,8 @@ class ZipSettings(DeliveryDictable):
         password: Optional password for the compressed file
         password_protect: Whether to password protect file or not
     """
+    _DELETE_NONE_VALUES_RECURSION = False
+
     VALIDATION_DICT = {
         "filename": [str, False],
         "password": [str, False],
@@ -113,6 +117,7 @@ class Delivery(DeliveryDictable):
         mobile: Mobile delivery properties object
         history_list: HistoryList delivery properties
     """
+    _DELETE_NONE_VALUES_RECURSION = False
 
     class DeliveryMode(AutoUpperName):
         EMAIL = auto()
@@ -144,6 +149,8 @@ class Delivery(DeliveryDictable):
                 in the history list
             zip: Optional compression settings object
         """
+        _DELETE_NONE_VALUES_RECURSION = False
+
         VALIDATION_DICT = {
             "subject": [str, True],
             "message": [str, False],
@@ -184,6 +191,8 @@ class Delivery(DeliveryDictable):
             burst_sub_folder:The burst sub folder
             zip: Optional compression settings object
         """
+        _DELETE_NONE_VALUES_RECURSION = False
+
         VALIDATION_DICT = {
             "filename": [str, False],
             "space_delimiter": [str, False],
@@ -211,6 +220,8 @@ class Delivery(DeliveryDictable):
             orientation: Whether orientation is portrait or landscape
             use_print_range: Whether a print range should be used
         """
+        _DELETE_NONE_VALUES_RECURSION = False
+
         VALIDATION_DICT = {
             "copies": [int, False],
             "range_start": [int, False],
@@ -240,6 +251,8 @@ class Delivery(DeliveryDictable):
             space_delimiter: The space delimiter
             zip: Optional compression settings object
         """
+        _DELETE_NONE_VALUES_RECURSION = False
+
         VALIDATION_DICT = {
             "filename": [str, False],
             "space_delimiter": [str, False],
@@ -263,6 +276,8 @@ class Delivery(DeliveryDictable):
             reuse_dataset_cache: Whether to reuse dataset cache
             is_all_library_users: Whether for all library users
         """
+        _DELETE_NONE_VALUES_RECURSION = False
+
         VALIDATION_DICT = {
             "library_cache_types": [list, False],
             "reuse_dataset_cache": [bool, False],
@@ -292,6 +307,8 @@ class Delivery(DeliveryDictable):
                 the history list
             re_run_hl: Whether the subscription will re-run against warehouse
         """
+        _DELETE_NONE_VALUES_RECURSION = False
+
         VALIDATION_DICT = {
             "client_type": [str, False],
             "device_id": [str, False],
@@ -321,6 +338,8 @@ class Delivery(DeliveryDictable):
                 the history list
             re_run_hl: Whether the subscription will re-run against warehouse
         """
+        _DELETE_NONE_VALUES_RECURSION = False
+
         VALIDATION_DICT = {
             "device_id": [str, False],
             "do_not_create_update_caches": [bool, False],
