@@ -1,4 +1,4 @@
-from typing import List, Union, Optional
+from typing import List, Optional, Union
 
 from mstrio.connection import Connection
 
@@ -9,6 +9,7 @@ from .content import Content
 
 class EmailSubscription(Subscription):
     """Class representation of MicroStrategy Email Subscription object."""
+    _DELETE_NONE_VALUES_RECURSION = False
 
     def __init__(self, connection: Connection, subscription_id: Optional[str] = None,
                  project_id: Optional[str] = None, project_name: Optional[str] = None):
