@@ -1,6 +1,8 @@
 # flake8: noqa
 from .attribute import *
+from .fact import *
 from .helpers import *
 from .schema_management import (SchemaLockStatus, SchemaLockType, SchemaManagement, SchemaTask,
                                 SchemaTaskStatus, SchemaUpdateType)
 from .user_hierarchy import *
+from .table import *
