@@ -6,39 +6,56 @@ import requests
 from tqdm.auto import tqdm
 
 from mstrio import config
-from mstrio.api import reports
-from mstrio.object_management.search_operations import full_search, SearchPattern
+from mstrio.api import objects, reports
 from mstrio.connection import Connection
+from mstrio.object_management.search_operations import full_search, SearchPattern
 from mstrio.users_and_groups.user import User
 from mstrio.utils.certified_info import CertifiedInfo
-from mstrio.utils.entity import CertifyMixin, DeleteMixin, Entity, ObjectTypes
+from mstrio.utils.entity import (
+    CertifyMixin, CopyMixin, DeleteMixin, Entity, MoveMixin, ObjectTypes
+)
 from mstrio.utils.filter import Filter
-from mstrio.utils.helper import fallback_on_timeout
-import mstrio.utils.helper as helper
+from mstrio.utils.helper import (
+    deprecation_warning, exception_handler, fallback_on_timeout, get_parallel_number,
+    response_handler, sort_object_properties
+)
 from mstrio.utils.parser import Parser
 from mstrio.utils.sessions import FuturesSessionWithRenewal
 
 
-def list_reports(connection: Connection, name_begins: Optional[str] = None,
-                 to_dictionary: bool = False, limit: Optional[int] = None,
-                 **filters) -> Union[List["Report"], List[dict]]:
+def list_reports(
+        connection: Connection,
+        name: Optional[str] = None,
+        name_begins: Optional[str] = None,
+        search_pattern: Union[SearchPattern, int] = SearchPattern.CONTAINS,
+        project_id: Optional[str] = None,
+        to_dictionary: bool = False,
+        limit: Optional[int] = None,
+        **filters,
+) -> Union[List["Report"], List[dict]]:
     """Get list of Report objects or dicts with them.
-    Optionally filter reports by specifying 'name_begins'.
+    Optionally filter reports by specifying 'name'.
 
     Optionally use `to_dictionary` to choose output format.
 
     Wildcards available for 'name_begins':
         ? - any character
         * - 0 or more of any characters
-        e.g name_begins = ?onny wil return Sonny and Tonny
+        e.g. name_begins = ?onny will return Sonny and Tonny
 
     Args:
         connection: MicroStrategy connection object returned by
             `connection.Connection()`
-        name_begins (string, optional): characters that the report name must
-            begin with
+        name (string, optional): value the search pattern is set to, which
+            will be applied to the names of reports being searched
+        name_begins (string, optional): deprecated. Use `name` instead.
         to_dictionary (bool, optional): If True returns dict, by default (False)
             returns Report objects
+        search_pattern (SearchPattern enum or int, optional): pattern to search
+            for, such as Begin With or Contains. Possible values are available
+            in ENUM mstrio.browsing.SearchPattern.
+            Default value is BEGIN WITH (4).
+        project_id (string, optional): Project ID
         limit (integer, optional): limit the number of elements returned. If
             None all object are returned.
         **filters: Available filter parameters: ['id', 'name', 'type',
@@ -48,17 +65,32 @@ def list_reports(connection: Connection, name_begins: Optional[str] = None,
     Returns:
         list with Report objects or list of dictionaries
     """
-    connection._validate_project_selected()
-    objects_ = full_search(connection, object_types=ObjectTypes.REPORT_DEFINITION,
-                           project=connection.project_id, name=name_begins,
-                           pattern=SearchPattern.BEGIN_WITH, limit=limit, **filters)
+    if project_id is None:
+        connection._validate_project_selected()
+        project_id = connection.project_id
+    if name_begins:
+        deprecation_warning(
+            "`name_begins`",
+            "`name`",
+            "11.3.7.101",  # NOSONAR
+            False
+        )
+        name, search_pattern = name_begins, SearchPattern.BEGIN_WITH
+    objects_ = full_search(
+        connection,
+        object_types=ObjectTypes.REPORT_DEFINITION,
+        project=project_id,
+        name=name,
+        pattern=search_pattern,
+        limit=limit,
+        **filters,
+    )
     if to_dictionary:
         return objects_
-    else:
-        return [Report.from_dict(obj_, connection) for obj_ in objects_]
+    return [Report.from_dict(obj_, connection) for obj_ in objects_]
 
 
-class Report(Entity, CertifyMixin, DeleteMixin):
+class Report(Entity, CertifyMixin, CopyMixin, MoveMixin, DeleteMixin):
     """Access, filter, publish, and extract data from in-memory reports.
 
     Create a Report object to load basic information on a report dataset.
@@ -104,6 +136,8 @@ class Report(Entity, CertifyMixin, DeleteMixin):
         'certified_info': CertifiedInfo.from_dict,
     }
     _SIZE_LIMIT = 10000000  # this sets desired chunk size in bytes
+    _DELETE_NONE_VALUES_RECURSION = False
+    _API_PATCH: dict = {**Entity._API_PATCH, ('folder_id'): (objects.update_object, 'partial_put')}
 
     def __init__(self, connection: Connection, id: str, instance_id: Optional[str] = None,
                  parallel: bool = True, progress_bar: bool = True):
@@ -180,7 +214,6 @@ class Report(Entity, CertifyMixin, DeleteMixin):
         """
         if limit:
             self._initial_limit = limit
-            self.instance_id = None
 
         if self.instance_id is None:
             res = self.__initialize_report(self._initial_limit)
@@ -211,7 +244,7 @@ class Report(Entity, CertifyMixin, DeleteMixin):
                 ((paging['total'] - self._initial_limit) % limit != 0)
 
             if self._parallel and it_total > 1:
-                threads = helper.get_parallel_number(it_total)
+                threads = get_parallel_number(it_total)
                 with FuturesSessionWithRenewal(connection=self._connection,
                                                max_workers=threads) as session:
                     fetch_pbar = tqdm(desc="Downloading", total=it_total + 1,
@@ -221,7 +254,7 @@ class Report(Entity, CertifyMixin, DeleteMixin):
                     for i, f in enumerate(future, start=1):
                         response = f.result()
                         if not response.ok:
-                            helper.response_handler(response, "Error getting report contents.")
+                            response_handler(response, "Error getting report contents.")
                         fetch_pbar.update()
                         fetch_pbar.set_postfix(
                             rows=str(min(self._initial_limit + i * limit, paging['total'])))
@@ -259,7 +292,7 @@ class Report(Entity, CertifyMixin, DeleteMixin):
                                             self.attributes))[0]['name']
                     elements = attr_dict[attribute]
                     indexes = indexes | self._dataframe[attr_name].isin(elements)
-                # select datframe indexes with
+                # select dataframe indexes with
                 self._dataframe = self._dataframe[indexes]
 
             if self._cross_tab_filter['attributes'] is not None:
@@ -268,7 +301,7 @@ class Report(Entity, CertifyMixin, DeleteMixin):
                         filter(lambda x: x['id'] not in self._cross_tab_filter['attributes'],
                                self.attributes))
                 ]
-                # filtering out attribute forms cloumns
+                # filtering out attribute forms columns
                 to_be_removed = []
                 to_be_added = []
                 for attr in attr_names:
@@ -425,11 +458,15 @@ class Report(Entity, CertifyMixin, DeleteMixin):
 
         # Check if report have custom groups or consolidations
         if available_objects['customGroups']:
-            helper.exception_handler(msg="Reports with custom groups are not supported.",
-                                     exception_type=ImportError)
+            exception_handler(
+                msg="Reports with custom groups are not supported.",
+                exception_type=ImportError,
+            )
         if available_objects['consolidations']:
-            helper.exception_handler(msg="Reports with consolidations are not supported.",
-                                     exception_type=ImportError)
+            exception_handler(
+                msg="Reports with consolidations are not supported.",
+                exception_type=ImportError,
+            )
 
         full_attributes = []
         for row in grid["rows"]:
@@ -510,7 +547,7 @@ class Report(Entity, CertifyMixin, DeleteMixin):
 
         attr_elements = []
         if self.attributes:
-            threads = helper.get_parallel_number(len(self.attributes))
+            threads = get_parallel_number(len(self.attributes))
             with FuturesSessionWithRenewal(connection=self._connection,
                                            max_workers=threads) as session:
                 # Fetch first chunk of attribute elements.
@@ -521,8 +558,9 @@ class Report(Entity, CertifyMixin, DeleteMixin):
                     attr = self.attributes[i]
                     response = future.result()
                     if not response.ok:
-                        helper.response_handler(
-                            response, "Error getting attribute " + attr['name'] + " elements")
+                        response_handler(
+                            response, f"Error getting attribute {attr['name']} elements"
+                        )
                     elements = response.json()
                     # Get total number of rows from headers.
                     total = int(response.headers['x-mstr-total-count'])
@@ -581,7 +619,7 @@ class Report(Entity, CertifyMixin, DeleteMixin):
             "metrics": self.metrics
         }
         return {
-            key: attributes[key] for key in sorted(attributes, key=helper.sort_object_properties)
+            key: attributes[key] for key in sorted(attributes, key=sort_object_properties)
         }
 
     @property
@@ -638,7 +676,8 @@ class Report(Entity, CertifyMixin, DeleteMixin):
     @property
     def dataframe(self) -> pd.DataFrame:
         if self._dataframe is None:
-            helper.exception_handler(
+            exception_handler(
                 msg="Dataframe not loaded. Retrieve with Report.to_dataframe().",
-                exception_type=Warning)
+                exception_type=Warning,
+            )
         return self._dataframe
