@@ -1,32 +1,32 @@
+import inspect
+import logging
+import os
+import re
+import warnings
 from datetime import datetime
 from enum import Enum
 from functools import reduce, wraps
-import inspect
 from json.decoder import JSONDecodeError
-from math import floor
-import os
-import re
 from typing import Any, Callable, Dict, List, Optional, Tuple, TYPE_CHECKING, TypeVar, Union
-import warnings
 
 import pandas as pd
 import stringcase
-
 from mstrio import __version__ as mstrio_version
 from mstrio import config
 from mstrio.api.exceptions import MstrTimeoutError, PromptedContentError, VersionException
 from mstrio.types import ObjectSubTypes
 from mstrio.utils.dict_filter import filter_list_of_dicts
 from mstrio.utils.enum_helper import get_enum_val
-from mstrio.utils.time_helper import DatetimeFormats, map_datetime_to_str, map_str_to_datetime
 from mstrio.utils.sessions import FuturesSessionWithRenewal
-
+from mstrio.utils.time_helper import DatetimeFormats, map_datetime_to_str, map_str_to_datetime
 
 if TYPE_CHECKING:
     from mstrio.connection import Connection
     from mstrio.project_objects.datasets import OlapCube, SuperCube
     from mstrio.types import ObjectTypes
 
+logger = logging.getLogger(__name__)
+
 
 def deprecation_warning(deprecated: str, new: str, version: str, module: bool = True,
                         change_compatible_immediately=True):
@@ -101,7 +101,7 @@ def camel_to_snake(response: Union[dict, list]) -> Union[dict, List[dict]]:
     def convert_dict(source):
         return {
             stringcase.snakecase(key):
-            value if not isinstance(value, dict) else convert_dict(value)
+                value if not isinstance(value, dict) else convert_dict(value)
             for key, value in source.items()
         }
 
@@ -120,7 +120,7 @@ def snake_to_camel(response: Union[dict, list]) -> Union[dict, List[dict]]:
     def convert_dict(source):
         return {
             stringcase.camelcase(key):
-            value if not isinstance(value, dict) else convert_dict(value)
+                value if not isinstance(value, dict) else convert_dict(value)
             for key, value in source.items()
         }
 
@@ -153,6 +153,12 @@ def exception_handler(msg, exception_type=Exception, stack_lvl=2):
         warnings.warn(msg, exception_type, stacklevel=stack_lvl)
 
 
+class IServerError(IOError):
+    def __init__(self, message, http_code):
+        super().__init__(message)
+        self.http_code = http_code
+
+
 def response_handler(response, msg, throw_error=True, verbose=True, whitelist=None):
     """Generic error message handler for transactions against I-Server.
 
@@ -170,6 +176,9 @@ def response_handler(response, msg, throw_error=True, verbose=True, whitelist=No
         whitelist = []
 
     try:
+        logger.debug(f"{response} url = '{response.url}'")
+        logger.debug(f"headers = {response.headers}")
+        logger.debug(f"content = {response.text}")
         res = response.json()
 
         if res.get('errors') is not None:
@@ -200,16 +209,25 @@ def response_handler(response, msg, throw_error=True, verbose=True, whitelist=No
                 raise PromptedContentError(
                     'Prompted content subscription creation is not supported.')
             if verbose:
-                print(msg)
-                print("I-Server Error %s, %s\nTicket ID: %s\n" %
-                      (server_code, server_msg, ticket_id))
+                logger.error(
+                    f'{msg}\n'
+                    f'I-Server Error {server_code}, {server_msg}\n'
+                    f'Ticket ID: {ticket_id}'
+                )
             if throw_error:
-                response.raise_for_status()
+                raise IServerError(
+                    message=f"{server_msg}; code: '{server_code}', ticket_id: '{ticket_id}'",
+                    http_code=response.status_code
+                )
     except JSONDecodeError:
+        logger.debug(f"Response body: {response.text}")
+
         if verbose:
-            print(msg)
-            print(("Could not decode the response from the I-Server. Please check if I-Server "
-                   "is running correctly\n"))
+            logger.error(
+                f'{msg}\n'
+                f'Could not decode the response from the I-Server. Please check if I-Server is '
+                f'running correctly'
+            )
             response.raise_for_status()  # raise error if I-Server response cannot be decoded
 
 
@@ -234,10 +252,12 @@ def fallback_on_timeout(min_limit: int = 50):
             try:
                 return func(limit), limit
             except MstrTimeoutError as err:
-                new_limit = floor(limit / 2)
+                new_limit = limit // 2
                 if new_limit >= min_limit:
-                    warnings.warn((f"Timout hit when executing {func.__name__} with limit "
-                                   f"{limit}, retrying with limit {new_limit}"))
+                    logger.warning(
+                        f'Timout hit when executing {func.__name__} with limit {limit}, '
+                        f'retrying with limit {new_limit}'
+                    )
                     return fot_wrapper(new_limit)
                 else:
                     raise err
@@ -381,13 +401,16 @@ def sort_object_properties(source: dict) -> int:
     return preffered_order.get(source, 50)
 
 
-def auto_match_args(func: Callable, param_dict: dict, exclude: list = [],
+def auto_match_args(func: Callable, param_dict: dict, exclude: Optional[list] = None,
                     include_defaults: bool = True) -> dict:
     """Automatically match dict data to function arguments.
 
     Handles default parameters. Extracts value from Enums. Returns matched
     arguments as dict.
 
+    Note: don't use it for alter purposes as, changing parameter value
+        back to default currently doesn't work (Rework line 413?)
+
     Args:
         function: function for which args will be matched
         param_dict: dict to use for matching the function args
@@ -398,6 +421,7 @@ def auto_match_args(func: Callable, param_dict: dict, exclude: list = [],
         KeyError: could not match all required arguments
     """
 
+    exclude = exclude or []
     args = get_args_from_func(func)
     default_dict = get_default_args_from_func(func)
 
@@ -435,12 +459,13 @@ def dict_compare(d1, d2):
     added = d1_keys - d2_keys
     removed = d2_keys - d1_keys
     modified = {o: (d1[o], d2[o]) for o in intersect_keys if d1[o] != d2[o]}
-    same = set(o for o in intersect_keys if d1[o] == d2[o])
+    same = {o for o in intersect_keys if d1[o] == d2[o]}
     return added, removed, modified, same
 
 
 def __validate_single_param_value(value, param_name, data_type, max_val, min_val, regex,
-                                  valid_example, inv_val, special_values=[]):
+                                  valid_example, inv_val, special_values=None):
+    special_values = special_values or []
     if value in special_values:
         return True
 
@@ -466,7 +491,7 @@ def __validate_single_param_value(value, param_name, data_type, max_val, min_val
 
 
 def validate_param_value(param_name, param_val, data_type, max_val=None, min_val=None,
-                         special_values=[], regex=None, exception=True,
+                         special_values=None, regex=None, exception=True,
                          valid_example=None) -> bool:
     """Validate param data type and optionally max, min special values.
 
@@ -474,6 +499,7 @@ def validate_param_value(param_name, param_val, data_type, max_val=None, min_val
         TypeError
         ValueError
     """
+    special_values = special_values or []
     inv_type = TypeError if exception else Warning
     inv_val = ValueError if exception else Warning
     data_type = data_type if isinstance(data_type, list) else [data_type]
@@ -504,18 +530,27 @@ def extract_all_dict_values(list_of_dicts: List[Dict]) -> List[Any]:
     return all_options
 
 
-def delete_none_values(source: dict) -> dict:
+def delete_none_values(source: dict, *, whitelist_attributes: Optional[list] = None,
+                       recursion: bool) -> dict:
     """Delete keys with None values from dictionary.
 
     Args:
         source (dict): dict object from which none values will be deleted
+        whitelist_attributes (list): keyword-only argument containing name
+            of attribute, which should be left alone even if they contain
+            none values
+        recursion (bool): flag that turns recursion on or off
     """
+    whitelist = whitelist_attributes or []
+
     new_dict = {}
     for key, value in source.items():
-        if isinstance(value, dict):
-            new_dict[key] = delete_none_values(value)
-        elif value not in [[], {}, None]:
+        if recursion and isinstance(value, dict):
+            new_dict[key] = delete_none_values(value, whitelist_attributes=whitelist,
+                                               recursion=recursion)
+        elif value not in [[], {}, None] or key in whitelist:
             new_dict[key] = value
+
     return new_dict
 
 
@@ -658,8 +693,8 @@ def merge_id_and_type(object_id: str, object_type: Union["ObjectTypes", "ObjectS
         exception_handler(msg=error_msg or "Please provide both `id` and `type`.",
                           exception_type=AttributeError)
     object_id = get_objects_id(object_id, type(object_id))
-    object_type = get_enum_val(object_type, type(object_type)) if isinstance(
-        object_type, Enum) else object_type
+    object_type = get_enum_val(object_type, type(object_type)) if isinstance(object_type,
+                                                                             Enum) else object_type
     return f'{object_id};{object_type}'
 
 
@@ -706,6 +741,37 @@ def rgetattr(obj, attr, *default):
     return reduce(_getattr, [obj] + attr.split('.'))
 
 
+def filter_params_for_func(func: Callable, params: dict, exclude: Optional[list] = None) -> dict:
+    """Filter dict of parameters and return only those that are parameters
+    of a `func`.
+    Mainly used in `EntityBase.alter()`, before calling
+    `EntityBase._alter_properties()` as shown in `Example`.
+
+    Args:
+        func: a function that the params are going to be fit for
+        params: a dict with parameters that will be filtered
+        exclude: set `exclude` parameter to exclude specific param-value pairs
+    Returns:
+        a dict with parameters of `func` that exist in `params` dict
+    Example:
+        params = filter_params_for_func(self.alter, locals())
+        self._alter_properties(**params)
+    """
+    args = get_args_from_func(func)
+    defaults_dict = get_default_args_from_func(func)
+    exclude = exclude or []
+    properties = {}
+
+    for arg in args:
+        if arg in exclude:
+            continue
+        elif params.get(arg, None) is not None:
+            properties.update({arg: params.get(arg)})
+        elif defaults_dict.get(arg, None) is not None:
+            properties.update({arg: defaults_dict.get(arg)})
+    return properties
+
+
 T = TypeVar("T")
 
 
@@ -729,11 +795,45 @@ def choose_cube(connection: "Connection", cube_dict: dict) -> Union["OlapCube",
         return SuperCube.from_dict(cube_dict, connection)
 
 
+def get_valid_project_id(connection: "Connection", project_id: Optional[str] = None,
+                         project_name: Optional[str] = None, with_fallback: bool = False):
+    from mstrio.server import Project
+    # Search for a project by its name if id was not specified, but name was
+    if not project_id:
+        try:
+            project_id = Project(connection=connection, name=project_name).id
+        except ValueError:
+            # If project with a given name was not found, try to use a
+            # project specified during initialisation of `connection` obj.
+            if with_fallback:
+                project_id = fallback_to_conn_project_id(connection)
+            else:
+                exception_handler(msg="Project could not be determined.",
+                                  exception_type=ValueError)
+    return project_id
+
+
+def fallback_to_conn_project_id(connection: "Connection") -> Optional[str]:
+    try:
+        connection._validate_project_selected()
+        return connection.project_id
+    except AttributeError:
+        exception_handler(msg="Project could not be determined.",
+                          exception_type=ValueError)
+
+
 class Dictable:
+    """The fundamental class in mstrio-py package. Includes support for
+    converting an object to a dictionary, and creating an object from a
+    dictionary."""
     _FROM_DICT_MAP: Dict[str, Callable] = {}  # map attributes to Enums and components
+    # list of attribute name, which are allowed to have none values
+    # in dict returned by .to_dict()
+    _ALLOW_NONE_ATTRIBUTES: List[str] = []
+    _DELETE_NONE_VALUES_RECURSION: bool  # enable or disable recursion in delete_none_values
 
     @classmethod
-    def _obj_to_dict(cls, key, val, camel_case=True):
+    def _unpack_objects(cls, key, val, camel_case=True):
         """Unpack Enums, Dictable obj, list of Enums"""
         if isinstance(val, datetime):
             return map_datetime_to_str(key, val, cls._FROM_DICT_MAP)
@@ -742,55 +842,94 @@ class Dictable:
         elif isinstance(val, Dictable):
             return val.to_dict(camel_case)
         elif isinstance(val, list):
-            return [cls._obj_to_dict(key, v, camel_case) for v in val]
+            return [cls._unpack_objects(key, v, camel_case) for v in val]
         return val
 
     @classmethod
     def _dict_to_obj(cls, connection, val, key):
 
         def constructor():
-            if isinstance(val, type(DatetimeFormats)):
+            if isinstance(cls._FROM_DICT_MAP[key], DatetimeFormats):
                 return map_str_to_datetime(key, val, cls._FROM_DICT_MAP)
             elif isinstance(cls._FROM_DICT_MAP[key], type(Enum)):
                 return cls._FROM_DICT_MAP[key](val)
             elif isinstance(cls._FROM_DICT_MAP[key], type(Dictable)):
                 return cls._FROM_DICT_MAP[key].from_dict(val)
             elif isinstance(cls._FROM_DICT_MAP[key], list):
-                if (all(isinstance(v, type(Enum)) for v in cls._FROM_DICT_MAP[key])
-                        and val is not None):
+                if isinstance(cls._FROM_DICT_MAP[key][0], list):
+                    # for: List[List[handling_cls]]
+                    handling_cls = cls._FROM_DICT_MAP[key][0][0]
+                    return [[handling_cls.from_dict(item) for item in v] for v in val]
+                elif (all(isinstance(v, type(Enum)) for v in cls._FROM_DICT_MAP[key])
+                      and val is not None):
                     return [cls._FROM_DICT_MAP[key][0](v) for v in val]
                 elif all([isinstance(v, type(Dictable)) for v in cls._FROM_DICT_MAP[key]]):
                     return [cls._FROM_DICT_MAP[key][0].from_dict(v) for v in val]
+                elif callable(cls._FROM_DICT_MAP[key][0]):
+                    return [cls._FROM_DICT_MAP[key][0](v, connection) for v in val]
             else:
                 return cls._FROM_DICT_MAP[key](val, connection)
 
         return val if key not in cls._FROM_DICT_MAP else constructor()
 
-    def to_dict(self, camel_case=True):
+    def to_dict(self, camel_case: bool = True) -> dict:
+        """Converts an object to a dictionary excluding object's private
+        properties. When converting the object to a dictionary, the object's
+        attributes become the dictionary's keys and are in camel case by default
+        Attribute values stored as objects are automatically converted to
+        non-/ primitive data structures.
+
+        Args:
+            camel_case (bool, optional): Set to True if attribute names should
+                be converted from snake case to camel case. Defaults to True.
+
+        Returns:
+            dict: A dictionary representation of object's attributes and values.
+                By default the dictionary keys are in camel case.
+        """
 
         hidden_keys = [
             '_fetched_attributes', '_altered_properties', '_connection', 'connection', '_type'
         ]
         cleaned_dict = self.__dict__.copy()
-        properties = set(
-            (elem[0]
-             for elem in inspect.getmembers(self.__class__, lambda x: isinstance(x, property))))
+        properties = {
+            elem[0]
+            for elem in inspect.getmembers(self.__class__, lambda x: isinstance(x, property))}
         for prop in properties:
             to_be_deleted = '_' + prop
             cleaned_dict[prop] = cleaned_dict.pop(to_be_deleted, None)
         result = {
-            key: self._obj_to_dict(key, val, camel_case)
+            key: self._unpack_objects(key, val, camel_case)
             for key, val in cleaned_dict.items()
             if key not in hidden_keys
         }
 
-        result = delete_none_values(result)
+        result = delete_none_values(result, whitelist_attributes=self._ALLOW_NONE_ATTRIBUTES,
+                                    recursion=self._DELETE_NONE_VALUES_RECURSION)
         result = {key: result[key] for key in sorted(result, key=sort_object_properties)}
         return snake_to_camel(result) if camel_case else result
 
     @classmethod
     def from_dict(cls: T, source: Dict[str, Any], connection: Optional["Connection"] = None,
                   to_snake_case: bool = True) -> T:
+        """Creates an object from a dictionary. The dictionary's keys in camel
+        case are changed to object's attribute names (by default in snake case)
+        and dict values are composed to their proper data types such as Enums,
+        list of Enums etc. as specified in _FROM_DICT_MAP.
+
+        Args:
+            cls (T): Class (type) of an object that should be created.
+            source (Dict[str, Any]): A dictionary from which an object will be
+                constructed.
+            connection (Connection, optional): A MSTR Connection object.
+                Defaults to None.
+            to_snake_case (bool, optional): Set to True if attribute names
+                should be converted from camel case to snake case. Defaults to
+                True.
+
+        Returns:
+            T: An object of type T.
+        """
         object_source = camel_to_snake(source) if to_snake_case else source
         if connection is not None:
             object_source["connection"] = connection
@@ -802,3 +941,23 @@ class Dictable:
         }
         obj = cls(**args)  # type: ignore
         return obj
+
+    @classmethod
+    def bulk_from_dict(cls: T, source_list: list[dict[str, Any]],
+                       connection: Optional["Connection"] = None, to_snake_case: bool = True) -> T:
+        return [
+            cls.from_dict(source=source, connection=connection, to_snake_case=to_snake_case)
+            for source in source_list
+        ]
+
+    def __repr__(self) -> str:
+        from mstrio.utils.entity import auto_match_args_entity
+        param_dict = auto_match_args_entity(
+            self.__init__,
+            self,
+            exclude=['self'],
+            include_defaults=False,
+        )
+        formatted_params = ', '.join(
+            (f'{param}={repr(value)}' for param, value in param_dict.items()))
+        return f'{self.__class__.__name__}({formatted_params})'
