@@ -2,7 +2,7 @@ from builtins import type as get_type
 from enum import auto
 from typing import Optional, Union
 
-from mstrio.access_and_security.security_filter import ObjectReference, ObjectInformation
+from mstrio.access_and_security.security_filter import ObjectInformation, ObjectReference
 from mstrio.utils.enum_helper import AutoName
 from mstrio.utils.helper import Dictable
 
@@ -71,6 +71,7 @@ class ParserToken(Dictable):
             the context of an object (say `City@DESC`) then provide information
             about the attribute form.
     """
+    _DELETE_NONE_VALUES_RECURSION = False
 
     def __init__(self, value: str, type: Optional[Union[TokenTextType, str]] = None,
                  level: Optional[Union[TokenLevel, str]] = None,
